==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/mk.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Надворешни складишта",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Дозволи пристап",
    "Error configuring OAuth1" : "Грешка во конфигурацијата на OAuth1",
    "Please provide a valid app key and secret." : "Внесете валиден клуч на апликацијата и лозинка.",
    "Error configuring OAuth2" : "Грешка во конфигурацијата на OAuth2",
    "Generate keys" : "Генеригај клучеви",
    "Error generating key pair" : "Грешка при генерирање на клучеви",
    "All users. Type to select user or group." : "Сите корисници. Напишете за да изберете корисник или група.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Компатибилно со Mac NFD енкрипција (бавно)",
    "Enable encryption" : "Овозможи енкрипција",
    "Enable previews" : "Овозможи прегледување",
    "Enable sharing" : "Овозможи споделување",
    "Check for changes" : "Провери за промени",
    "Never" : "Никогаш",
    "Once every direct access" : "Еднаш секој пристап",
    "Read only" : "Само читај",
    "Delete" : "Избриши",
    "Admin defined" : "Дефинирано од администраторот",
    "Are you sure you want to delete this external storage?" : "Дали си сигурен дека сакаш да го избришеш ова надворешно складиште?",
    "Delete storage?" : "Избриши складиште?",
    "Saved" : "Снимено",
    "Saving..." : "Зачувува ...",
    "Save" : "Сними",
    "Empty response from the server" : "Нема одговор од серверот",
    "Couldn't access. Please log out and in again to activate this mount point" : "Неможе да се пристапи. Ве молиме одјавете се и повторно најавете се за да се активира монтираната точка.",
    "Couldn't get the information from the remote server: {code} {type}" : "Неможат да се превземат информациите од серверот: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Неможат да се превземе листата на надворешните монтирани точки: {type}",
    "There was an error with message: " : "Настана грешка со порака:",
    "External mount error" : "Грешка при надворешно монтирање",
    "external-storage" : "Надворешно складиште",
    "Please enter the credentials for the {mount} mount" : "Внесете акредитиви за {mount}",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Credentials saved" : "Акредитивите се зачувани",
    "Credentials saving failed" : "Неуспешно зачувување на акредитивите",
    "Credentials required" : "Акредитивите се задолжителни",
    "Storage with ID \"%d\" not found" : "Складиште со ID \"%d\" не е пронајдено",
    "Invalid mount point" : "Погрешна точка на монтирање",
    "Insufficient data: %s" : "Недоволни податоци: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Складиштето со ID \"%d\" неможе да се измени од корисник",
    "Access key" : "Клуч за пристап",
    "Secret key" : "Таен клуч",
    "Builtin" : "Вграден",
    "None" : "Ништо",
    "OAuth1" : "OAuth1",
    "App key" : "Клуч на апликацијата",
    "App secret" : "Тајна на апликацијата",
    "OAuth2" : "OAuth2",
    "Client ID" : "Клиент ИД",
    "Client secret" : "Тајна на клиент",
    "OpenStack v2" : "OpenStack v2",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "API key" : "API key",
    "Global credentials" : "Глобални акредитиви",
    "Log-in credentials, save in database" : "Акредитиви за најавување, зачувани во базата со податоци",
    "Username and password" : "Корисничко име и лозинка",
    "Log-in credentials, save in session" : "Акредитиви за најавување, зачувани во сесија",
    "Global credentials, user entered" : "Глобални акредитиви, внесени од корисник",
    "User entered, store in database" : "Внесени од корисник, зачувани во базата со податоци",
    "RSA public key" : "RSA јавен клуч",
    "Public key" : "Јавен клуч",
    "RSA private key" : "RSA приватен клуч",
    "Private key" : "Приватен клуч",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Име на серверот",
    "Port" : "Порта",
    "Region" : "Регион",
    "Enable SSL" : "Овозможи SSL",
    "WebDAV" : "WebDAV",
    "URL" : "Адреса",
    "Secure https://" : "Безбедна https://",
    "FTP" : "FTP",
    "Host" : "Домаќин",
    "Secure ftps://" : "Безбедна ftps://",
    "Local" : "Локален",
    "Location" : "Локација",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Сподели",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "Service name" : "Име на сервисот",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за cURL во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за FTP во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсалиран. Монтирањето на %2$s не е возможно. Контактирајте го администраторот.",
    "External storage support" : "Поддршка за надворешно складиште",
    "No external storage configured or you don't have the permission to configure them" : "Немате конфигурирано надворешно складиште или немате дозвола да го конфигурирате",
    "Name" : "Име",
    "Storage type" : "Вид на складиште",
    "Scope" : "Опсег",
    "Open documentation" : "Отвори ја документацијата",
    "Folder name" : "Име на папка",
    "External storage" : "External storage",
    "Authentication" : "Автентикација",
    "Configuration" : "Конфигурација",
    "Available for" : "Достапно за",
    "Click to recheck the configuration" : "Кликни за проверка на конфигурацијата",
    "Add storage" : "Додади складиште",
    "Advanced settings" : "Напредни параметри",
    "Allow users to mount external storage" : "Дозволи на корисниците да монтираат надворешни складишта",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните акредитиви можат да се искористат за пристапување во повеќе надворешни складишта кој користат исти акредитиви."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/mk.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Надворешни складишта",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Дозволи пристап",
    "Error configuring OAuth1" : "Грешка во конфигурацијата на OAuth1",
    "Please provide a valid app key and secret." : "Внесете валиден клуч на апликацијата и лозинка.",
    "Error configuring OAuth2" : "Грешка во конфигурацијата на OAuth2",
    "Generate keys" : "Генеригај клучеви",
    "Error generating key pair" : "Грешка при генерирање на клучеви",
    "All users. Type to select user or group." : "Сите корисници. Напишете за да изберете корисник или група.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Компатибилно со Mac NFD енкрипција (бавно)",
    "Enable encryption" : "Овозможи енкрипција",
    "Enable previews" : "Овозможи прегледување",
    "Enable sharing" : "Овозможи споделување",
    "Check for changes" : "Провери за промени",
    "Never" : "Никогаш",
    "Once every direct access" : "Еднаш секој пристап",
    "Read only" : "Само читај",
    "Delete" : "Избриши",
    "Admin defined" : "Дефинирано од администраторот",
    "Are you sure you want to delete this external storage?" : "Дали си сигурен дека сакаш да го избришеш ова надворешно складиште?",
    "Delete storage?" : "Избриши складиште?",
    "Saved" : "Снимено",
    "Saving..." : "Зачувува ...",
    "Save" : "Сними",
    "Empty response from the server" : "Нема одговор од серверот",
    "Couldn't access. Please log out and in again to activate this mount point" : "Неможе да се пристапи. Ве молиме одјавете се и повторно најавете се за да се активира монтираната точка.",
    "Couldn't get the information from the remote server: {code} {type}" : "Неможат да се превземат информациите од серверот: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Неможат да се превземе листата на надворешните монтирани точки: {type}",
    "There was an error with message: " : "Настана грешка со порака:",
    "External mount error" : "Грешка при надворешно монтирање",
    "external-storage" : "Надворешно складиште",
    "Please enter the credentials for the {mount} mount" : "Внесете акредитиви за {mount}",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Credentials saved" : "Акредитивите се зачувани",
    "Credentials saving failed" : "Неуспешно зачувување на акредитивите",
    "Credentials required" : "Акредитивите се задолжителни",
    "Storage with ID \"%d\" not found" : "Складиште со ID \"%d\" не е пронајдено",
    "Invalid mount point" : "Погрешна точка на монтирање",
    "Insufficient data: %s" : "Недоволни податоци: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Складиштето со ID \"%d\" неможе да се измени од корисник",
    "Access key" : "Клуч за пристап",
    "Secret key" : "Таен клуч",
    "Builtin" : "Вграден",
    "None" : "Ништо",
    "OAuth1" : "OAuth1",
    "App key" : "Клуч на апликацијата",
    "App secret" : "Тајна на апликацијата",
    "OAuth2" : "OAuth2",
    "Client ID" : "Клиент ИД",
    "Client secret" : "Тајна на клиент",
    "OpenStack v2" : "OpenStack v2",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "API key" : "API key",
    "Global credentials" : "Глобални акредитиви",
    "Log-in credentials, save in database" : "Акредитиви за најавување, зачувани во базата со податоци",
    "Username and password" : "Корисничко име и лозинка",
    "Log-in credentials, save in session" : "Акредитиви за најавување, зачувани во сесија",
    "Global credentials, user entered" : "Глобални акредитиви, внесени од корисник",
    "User entered, store in database" : "Внесени од корисник, зачувани во базата со податоци",
    "RSA public key" : "RSA јавен клуч",
    "Public key" : "Јавен клуч",
    "RSA private key" : "RSA приватен клуч",
    "Private key" : "Приватен клуч",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Име на серверот",
    "Port" : "Порта",
    "Region" : "Регион",
    "Enable SSL" : "Овозможи SSL",
    "WebDAV" : "WebDAV",
    "URL" : "Адреса",
    "Secure https://" : "Безбедна https://",
    "FTP" : "FTP",
    "Host" : "Домаќин",
    "Secure ftps://" : "Безбедна ftps://",
    "Local" : "Локален",
    "Location" : "Локација",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Сподели",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "Service name" : "Име на сервисот",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за cURL во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за FTP во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсалиран. Монтирањето на %2$s не е возможно. Контактирајте го администраторот.",
    "External storage support" : "Поддршка за надворешно складиште",
    "No external storage configured or you don't have the permission to configure them" : "Немате конфигурирано надворешно складиште или немате дозвола да го конфигурирате",
    "Name" : "Име",
    "Storage type" : "Вид на складиште",
    "Scope" : "Опсег",
    "Open documentation" : "Отвори ја документацијата",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Надворешното складирање ви овозможува да ги монтирате услугите и уредите за надворешно складирање како секундарни уреди за складирање на Nextcloud. Вие исто така може да им дозволите на корисниците да монтираат свои услуги за надворешно складирање.",
    "Folder name" : "Име на папка",
    "External storage" : "Надворешно складиште",
    "Authentication" : "Автентикација",
    "Configuration" : "Конфигурација",
    "Available for" : "Достапно за",
    "Click to recheck the configuration" : "Кликни за проверка на конфигурацијата",
    "Add storage" : "Додади складиште",
    "Advanced settings" : "Напредни параметри",
    "Allow users to mount external storage" : "Дозволи на корисниците да монтираат надворешни складишта",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните акредитиви можат да се искористат за пристапување во повеќе надворешни складишта кој користат исти акредитиви."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
